<?php
namespace Ak\Form;

/**
 * Naši dodaci osnovnoj klasi za element.
 *
 * @package Ak\Form
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/form
 */
trait ElementTrait
{
    private string $additionalInfo = '';


    /**
     * Postavlja postavke elementa.
     *
     * @param array $options
     */
    public function setOptions(iterable $options): void
    {
        parent::setOptions($options);

        if (isset($options['additional_info'])) {
            $this->setAdditionalInfo($options['additional_info']);
        }
    }

    /**
     * Vraća vrijednost ID atributa. Ako ne postoji automatski se generira.
     *
     * @return string
     */
    public function getId(): string
    {
        if (!isset($this->attributes['id'])) {
            $id = $this->generateId();
            $this->setAttribute('id', $id);
            return $id;
        }

        return parent::getAttribute('id');
    }



    /**
     * Vraća tekst pomoći za element.
     *
     * @return null|string
     */
    public function getAdditionalInfo(): ?string
    {
        return $this->additionalInfo;
    }

    /**
     * Postavlja tekst pomoći za element.
     *
     * @param string $additionalInfo
     */
    public function setAdditionalInfo(string $additionalInfo): void
    {
        $this->additionalInfo = $additionalInfo;
    }

    /**
     * Retrieve a single element attribute.
     *
     * @param  string $key
     * @return mixed
     */
    public function getAttribute(string $key)
    {
        return 'id' === $key
            ? $this->getId()
            : parent::getAttribute($key);
    }

    /**
     * Retrieve all attributes at once
     *
     * @return array
     */
    public function getAttributes(): array
    {
        $attributes = parent::getAttributes();

        if (empty($attributes['id'])) {
            $attributes['id'] = $this->getId();
        }

        return $attributes;
    }

    /**
     * Does the element has a specific attribute ?
     *
     * @param  string $key
     * @return bool
     */
    public function hasAttribute(string $key): bool
    {
        return 'id' === $key || parent::hasAttribute($key);
    }

    /**
     * Generira random string za ID elementa.
     *
     * @return string
     */
    private function generateId(): string
    {
        return substr(md5(rand() . time()), 0, 8);
    }
}
