<?php
namespace Ak\Form\View\Helper;

use Laminas\Form\ElementInterface;
use Laminas\Form\View\Helper\AbstractHelper;

/**
 * Renderira dodatne informacije uz element obrasca.
 *
 * @package Ak\Form\View\Helper
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/form
 */
final class FormAdditionalInfo extends AbstractHelper
{
    /**
     * @param ElementInterface|null $element
     * @return $this|string
     */
    public function __invoke(ElementInterface $element = null)
    {
        if (null === $element) {
            return $this;
        }

        return $this->render($element);
    }

    /**
     * Renderira tekst informacija.
     *
     * @param ElementInterface $element
     * @return string
     */
    public function render(ElementInterface $element): string
    {
        if (!$element instanceof \Ak\Form\ElementInterface) {
            return '';
        }

        if ($additionalInfo = $element->getAdditionalInfo()) {
            return sprintf('<div class="FormControl__AdditionalInfo">%s</div>', $additionalInfo);
        }

        return '';
    }

    /**
     * Renderira ikonu koja otvara dodatne informacije.
     *
     * @param string $content
     * @return string
     */
    public function renderButton(string $content = ''): string
    {
        return sprintf('<a href="#" class="FormControl__AdditionalInfoButton">%s</a>', $content);
    }
}
