<?php
namespace Ak\Form\View\Helper;

use Ak\Form\Element\Button;
use Ak\View\IconAwareInterface;
use Laminas\Form\ElementInterface;
use Laminas\Form\LabelAwareInterface;
use Laminas\Form\View\Helper\FormButton as BaseFormButton;

/**
 * Renderira <button> element.
 *
 * @package Ak\Form\View\Helper
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/form
 */
final class FormButton extends BaseFormButton
{
    use HelperTools;

    protected ?FormIcon $formIconHelper = null;

    /**
     * @return FormIcon
     */
    protected function getFormIconHelper(): FormIcon
    {
        if (null === $this->formIconHelper) {
            $this->formIconHelper = method_exists($this->view, 'plugin')
                ? $this->view->plugin('form_icon')
                : new FormIcon();
        }

        return $this->formIconHelper;
    }

    /**
     * Renderira button.
     *
     * @param ElementInterface $element Element.
     *
     * @param null $buttonContent
     *
     * @return string
     */
	public function render(ElementInterface $element, $buttonContent = null): string
	{
	    if ($element instanceof Button) {
            if ($style = $element->getStyle()) {
                $this->addCssClass($element, 'Button_style_' . $style);
            }
        }

        $this->addCssClass($element, ['Button']);

        if (
            $element instanceof IconAwareInterface &&
            $element instanceof LabelAwareInterface &&
            strlen($element->getIcon()) > 0
        ) {
	        $formIconHelper = $this->getFormIconHelper();
	        $element->setLabelOption('disable_html_escape', true);
	        $buttonContent = $formIconHelper($element);
        }

        return parent::render($element, $buttonContent);
	}
}
