<?php
namespace Ak\Form\View\Helper;

use Ak\Form\Element\Button;
use Laminas\Form\Element\Hidden;
use Laminas\Form\ElementInterface;
use Laminas\Form\View\Helper\AbstractHelper;

/**
 * Renderira kontrolu obrasca.
 *
 * @package Ak\Form\View\Helper
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/form
 */
final class FormControl extends AbstractHelper
{
    use HelperTools;

    /** @var FormAdditionalInfo */
    private $formAdditionalInfoHelper;
    /** @var FormElementDelegate */
    private $formElementDelegateHelper;
    /** @var FormElementErrors */
    private $formElementErrorsHelper;
    /** @var FormElementDescription */
    private $formElementDescription;

    /**
     * @param ElementInterface|null $element
     * @return $this|string
     */
    public function __invoke(ElementInterface $element = null)
    {
        if (null === $element) {
            return $this;
        }

        return $this->render($element);
    }

    /**
     * @return FormAdditionalInfo
     */
    public function getFormAdditionalInfoHelper()
    {
        if (null === $this->formAdditionalInfoHelper) {
            $this->formAdditionalInfoHelper = method_exists($this->view, 'plugin')
                ? $this->view->plugin('form_additional_info')
                : new FormAdditionalInfo();
        }

        return $this->formAdditionalInfoHelper;
    }

    /**
     * @return FormElementDelegate
     */
    public function getFormElementDelegateHelper()
    {
        if (null === $this->formElementDelegateHelper) {
            if (!method_exists($this->view, 'plugin')) {
                throw new \DomainException('Ovaj helper mora imati validan renderer.');
            }

            $this->formElementDelegateHelper = $this->view->plugin('form_element_delegate');
        }

        return $this->formElementDelegateHelper;
    }

    /**
     * @return FormElementErrors
     */
    public function getFormElementErrorsHelper()
    {
        if (null === $this->formElementErrorsHelper) {
            $this->formElementErrorsHelper = method_exists($this->view, 'plugin')
                ? $this->view->plugin('form_element_errors')
                : new FormElementErrors();
        }

        return $this->formElementErrorsHelper;
    }

    /**
     * @return FormElementDescription
     */
    protected function getFormElementDescriptionHelper(): FormElementDescription
    {
        if (null === $this->formElementDescription) {
            $this->formElementDescription = method_exists($this->view, 'plugin')
                ? $this->view->plugin('form_element_description')
                : new FormElementDescription();
        }

        return $this->formElementDescription;
    }

    /**
     * Renderira kontrolu.
     *
     * @param ElementInterface $element
     *
     * @return string
     */
    public function render(ElementInterface $element): string
    {
        $this->addCssClass($element, 'FormControl__Input');

        $formElementDelegateHelper = $this->getFormElementDelegateHelper();
        $formElementDescriptionHelper = $this->getFormElementDescriptionHelper();

        $control = $formElementDelegateHelper($element);

        if($element  instanceof Hidden || $element instanceof Button) {
            return $control;
        }

        if (count($element->getMessages()) > 0) {
            $formElementErrorsHelper = $this->getFormElementErrorsHelper();
            $attributes = $formElementErrorsHelper->getAttributes();
            $errors = $formElementErrorsHelper($element, [
                'class' => trim('FormControl__Errors ' . ($attributes['class'] ?? '')),
            ]);
        }

        if ($element instanceof \Ak\Form\ElementInterface && $element->getAdditionalInfo()) {
            $formAdditonalInfoHelper = $this->getFormAdditionalInfoHelper();
            $additionalInfo = $formAdditonalInfoHelper($element);
            $additionalInfoButton = $formAdditonalInfoHelper->renderButton('<i class="far fa-question-circle"></i>');
        }


        $description = $formElementDescriptionHelper($element);
        $inner = sprintf('<div class="FormControl__Inner">%s%s</div>', $control, $additionalInfoButton ?? '');

        return sprintf('<div class="FormControl">%s%s%s%s</div>', $inner, $description, $errors ?? '', $additionalInfo ?? '');
    }
}
