<?php
namespace Ak\Form\View\Helper;

use Ak\Form\Element\Checkbox;
use Laminas\Form\Element\MultiCheckbox as MultiCheckboxElement;
use Laminas\Form\View\Helper\FormMultiCheckbox as BaseFormMultiCheckbox;

/**
 * Renderira MultiCheckbox element.
 *
 * @package Ak\Form\View\Helper
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/form
 */
class FormMultiCheckbox extends BaseFormMultiCheckbox
{
    protected ?FormCheckbox $formCheckbox = null;

    /**
     * @return FormCheckbox
     */
    protected function getFormCheckboxHelper(): FormCheckbox
    {
        if (null === $this->formCheckbox) {
            $this->formCheckbox = is_object($this->view) && method_exists($this->view, 'plugin')
                ? $this->view->plugin('form_checkbox')
                : new FormCheckbox();
        }
        return $this->formCheckbox;
    }

    protected function renderOptions(
        MultiCheckboxElement $element,
        array $options,
        array $selectedOptions,
        array $attributes
    ): string {
        $form_checkbox = $this->getFormCheckboxHelper();
        $rendered = ['<a href="#" class="FormMultiCheckbox__ToggleAll">O(d)znači sve</a>'];

        foreach ($options as $value => $label) {
            $checkbox = new Checkbox($attributes['name'], [
                'label' => $label,
            ]);

            if ($checkboxAttributes = $element->getOption('checkbox_attributes')) {
                $checkbox->setAttributes($checkboxAttributes);
            }

            $checkbox->setUseHiddenElement(false);
            $checkbox->setCheckedValue($value);

            if (in_array($value, $selectedOptions)) {
                $checkbox->setChecked(true);
            }

            $rendered[] = $form_checkbox($checkbox);
        }

        return implode(PHP_EOL, $rendered);
    }
}
