<?php
namespace Ak\Form\View\Helper;

use Laminas\Form\ElementInterface;

/**
 * Alati za rendanje HTML obrazaca.
 *
 * @package Ak\Form\View\Helper
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/form
 */
trait HelperTools
{
    /**
     * Dodaje datu css klasu u element.
     *
     * @param ElementInterface $element
     * @param string|array $class
     * @param string $position
     */
    protected function addCssClass(ElementInterface $element, $class, string $position = 'prepend'): void
    {
        $classes = explode(' ', $element->getAttribute('class'));

        $class = !is_array($class) ? [$class] : $class;
        $class = array_diff($class, array_intersect($class, $classes));


        if (count($class) > 0) {
            switch ($position) {
                case 'append':
                    $classes = array_merge($classes, $class);
                    break;
                case 'prepend':
                    $classes = array_merge($class, $classes);
                    break;
                default:
                    throw new \RuntimeException(sprintf(
                        "Neispravna pozicija css klase, može biti samo 'append' ili 'prepend', a dobio sam '%s'.",
                        $position
                    ));
            }

            $element->setAttribute('class', trim(implode(' ', $classes)));
        }
    }

    /**
     * Uklanja css klasu iz elementa.
     *
     * @param ElementInterface $element
     * @param string|array $class
     */
    protected function removeCssClass(ElementInterface $element, $class): void
    {
        if (!is_array($class)) {
            $class = [$class];
        }

        $classes = explode(' ', $element->getAttribute('class'));

        foreach ($class as $cl) {
            if (($pos = array_search($cl, $classes)) > -1) {
                unset($classes[$pos]);
            }
        }

        $element->setAttribute('class', implode(' ', $classes));
    }
}
