<?php
namespace AkTest\Form;

use Ak\Form\Annotation\AnnotationBuilder;
use Ak\Form\ConfigProvider;
use Ak\Test\AbstractTestCase as BaseAbstractTestCase;
use Ak\Test\Dom\DOMTestTrait;
use Ak\View\HelperPluginManager;
use Laminas\ServiceManager\PluginManagerInterface;
use Laminas\View\Helper\HelperInterface;
use Psr\Container\ContainerExceptionInterface;
use Psr\Container\NotFoundExceptionInterface;

/**
 * Class AbstractTestCase
 *
 * @package AkTest\Form
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/form
 */
abstract class AbstractTestCase extends BaseAbstractTestCase
{
    use DOMTestTrait;

    protected array $providers = [
        \Ak\View\ConfigProvider::class,
        ConfigProvider::class,
    ];

    /**
     * @return PluginManagerInterface
     * @throws ContainerExceptionInterface
     * @throws NotFoundExceptionInterface
     */
    protected function getFormElementManager(): PluginManagerInterface
    {
        $container = $this->getContainer();
        return $container->get('FormElementManager');
    }

    /**
     * @return HelperPluginManager
     * @throws ContainerExceptionInterface
     * @throws NotFoundExceptionInterface
     */
    protected function getHelperPluginManager(): HelperPluginManager
    {
        $container = $this->getContainer();
        return $container->get(HelperPluginManager::class);
    }

    /**
     * @return AnnotationBuilder
     * @throws ContainerExceptionInterface
     * @throws NotFoundExceptionInterface
     */
    protected function getAnnotationBuilder(): AnnotationBuilder
    {
        $container = $this->getContainer();
        return $container->get('FormAnnotationBuilder');
    }

    /**
     * @param string $name
     *
     * @return HelperInterface|callable
     * @throws ContainerExceptionInterface
     * @throws NotFoundExceptionInterface
     */
    protected function getHelper(string $name): HelperInterface
    {
        $plugins = $this->getHelperPluginManager();
        return $plugins->get($name);
    }
}
