<?php
namespace AkTest\Form\View\Helper;

use Ak\Form\Element\Checkbox;
use Ak\Form\View\Helper\FormAdditionalInfo;
use Ak\Form\View\Helper\FormControl;
use Ak\Form\View\Helper\FormElementDelegate;
use Ak\Form\View\Helper\FormElementErrors;
use AkTest\Form\AbstractTestCase;
use AkTest\Form\Mock\HelperInterface;

/**
 * Class FormControlTest
 *
 * @package AkTest\Form\View\Helper
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/form
 */
class ControlTest extends AbstractTestCase
{
    public function testIsRegistered()
    {
        $manager = $this->getHelperPluginManager();

        $this->assertContainerHasService($manager, [
            'form_control',
            FormControl::class,
        ], FormControl::class, true);
    }

    public function testCorrectFormAdditionalInfoHelperIsUsed()
    {
        $element = new Checkbox('checkbox', [
            'additional_info' => 'info',
        ]);

        $formAdditionalInfoHelper = $this->createMock(HelperInterface::class);
        $formAdditionalInfoHelper->expects($this->once())
            ->method('__invoke')
            ->with($element)
            ->willReturn('');

        $manager = $this->getHelperPluginManager();
        $manager->setService(FormAdditionalInfo::class, $formAdditionalInfoHelper);

        $helper = $manager->get('form_control');
        $helper($element);
    }

    public function testCorrectFormElementHelperIsUsed()
    {
        $element = new Checkbox('checkbox');

        $formElementHelper = $this->createMock(HelperInterface::class);
        $formElementHelper->expects($this->once())
            ->method('__invoke')
            ->with($element)
            ->willReturn('');

        $manager = $this->getHelperPluginManager();
        $manager->setService(FormElementDelegate::class, $formElementHelper);

        $helper = $manager->get('form_control');
        $helper($element);
    }

    public function testCorrectFormElementErrorsIsUsed()
    {
        $element = new Checkbox('checkbox');
        $element->setMessages(['message']);

        $formElementErrorsHelper = $this->createMock(HelperInterface::class);
        $formElementErrorsHelper->expects($this->once())
            ->method('__invoke')
            ->with($element)
            ->willReturn('');

        $manager = $this->getHelperPluginManager();
        $manager->setService(FormElementErrors::class, $formElementErrorsHelper);

        $helper = $manager->get('form_control');
        $helper($element);
    }

    public function testWillRenderCheckbox()
    {
        $element = new Checkbox('checkbox');
        $helper = $this->getHelper('form_control');

        $rendered = $helper($element);

        $this->assertSelectCount('div.FormControl', 1, $rendered);
        $this->assertSelectCount('.FormControl .Checkbox.FormControl__Input', 1, $rendered);
        $this->assertSelectCount('div.FormControl input[type="checkbox"][name="checkbox"]', 1, $rendered);
    }

    public function testWillRenderElementErrors()
    {
        $element = new Checkbox('checkbox');
        $element->setMessages(['message']);
        $helper = $this->getHelper('form_control');

        $rendered = $helper($element);

        $this->assertSelectCount('div.FormControl > .FormControl__Errors', 1, $rendered);
    }

    public function testWillRenderAdditionalInfo()
    {
        $element = new Checkbox('checkbox', [
            'additional_info' => 'info',
        ]);

        $helper = $this->getHelper('form_control');
        $rendered = $helper($element);

        $this->assertSelectCount('.FormControl .FormControl__AdditionalInfo', 1, $rendered);
        $this->assertSelectCount('.FormControl .FormControl__AdditionalInfoButton', 1, $rendered);
    }
}